@@ -35,6 +35,10 @@ class ApiRun:
         self.POOL = redis.ConnectionPool(host=self.REDIS_IP, port=self.REDIS_PORT, db=self.REDIS_KEY,
                                          decode_responses=True)
         self.REDIS_POOL = redis.Redis(connection_pool=self.POOL)
+        # 初始日志文件的起始行号
+        self.initial_log_line = 0
+        # 初始日志文件的日期前缀
+        self.initial_log_time = ''
 
     @staticmethod
     def mkdir_and_del(src_path):
@@ -110,6 +114,60 @@ class ApiRun:
         details_file.write(str(sweet.report_data))
         details_file.close()
 
+    def read_log_file(self):
+        """
+        从以日期为维度统计的日志中提取出本次的日志文件，保存至log/new.log
+        """
+        # 如果日志文件的日期前缀不是当天的日期
+        if self.initial_log_time != time.strftime('%Y%m%d'):
+            # 重置日志文件的前缀、起始行数
+            self.initial_log_time = time.strftime('%Y%m%d')
+            self.initial_log_line = 0
+        # 读取日志文件的全部字符串
+        with open(os.path.join(os.getcwd(), 'log', time.strftime('%Y%m%d.log')), "r", encoding='utf-8') as f:
+            # 将日志字符串按换行符拆成列表
+            log_file_data = f.read().split('\n')
+        # 如果起始日志行反而比最大行数都大的话
+        if self.initial_log_line > len(log_file_data):
+            # 重置日志文件的起始行数
+            self.initial_log_line = 0
+        # 按行号增量取出本次测试的日志
+        log_file_list = log_file_data[self.initial_log_line:]
+        # 更新日志文件的起始行号
+        self.initial_log_line = len(log_file_data)
+        # 存储日志信息的字典
+        log_file_dict = {}
+        # 用这个变量控制每一行都是不重复的
+        previous_row = ''
+        # 整理每一行日志
+        for i in range(len(log_file_list)):
+            # 不读取空行
+            if log_file_list[i] == '':
+                continue
+            # 不读取和上一行重复的数据
+            if log_file_list[i] == previous_row:
+                continue
+            # 判断当前行是否包含特殊分割符
+            if ']: #  ' in log_file_list[i]:
+                # 将日志信息按用途分类
+                log_file_dict[i] = {
+                    'time': log_file_list[i][:23],
+                    'grade': log_file_list[i][25:log_file_list[i].find(']')],
+                    'message': log_file_list[i][log_file_list[i].find(']')+6:],
+                }
+            else:
+                # 如果是错误信息，上传特殊格式
+                log_file_dict[i] = {
+                    'time': '',
+                    'grade': '',
+                    'message': log_file_list[i].replace(' ', '&nbsp;'),
+                }
+            # 更新上一行的数据
+            previous_row = log_file_list[i]
+        # 在log目录下写入新的日志文件
+        with open(os.path.join('log', 'new.log'), "w", encoding='utf-8') as file:
+            file.write(json.dumps(log_file_dict))
+
     def post_heartbeat(self, status, localtime=None, task_dict=None, remark=None):
         """
         # 描述:
@@ -164,11 +222,16 @@ class ApiRun:
                     # 读取测试详情文件
                     with open(os.path.join('details', 'details.txt'), 'rb') as fp3:
                         files_details_obj = fp3.read()
-                    # 汇总XXX-Report@XXXXXX_XXX.xlsx、XXX-Report@XXXXXX_XXX.xml、details.txt文件对象
+                    # 读取测试日志文件
+                    self.read_log_file()
+                    with open(os.path.join('log', 'new.log'), 'rb') as fp4:
+                        files_log_obj = fp4.read()
+                    # 汇总XXX-Report@XXXXXX_XXX.xlsx、XXX-Report@XXXXXX_XXX.xml、details.txt、new.log文件对象
                     files_obj = {
                         'file_obj': (str(task_dict['queue_id']) + '.xlsx', files_report_obj),
                         'file_obj_junit': (str(task_dict['queue_id']) + '.xml', files_junit_obj),
-                        'file_obj_details': (str(task_dict['queue_id']) + '.txt', files_details_obj)
+                        'file_obj_details': (str(task_dict['queue_id']) + '.txt', files_details_obj),
+                        'file_obj_log': (str(task_dict['queue_id']) + '.log', files_log_obj)
                     }
                 else:
                     files_obj = {}
